import { PathEventEmitter } from '@ztimson/utils';
import { Api } from './api';
import { Meta } from './core';
export type Card = {
    number: number | string;
    expYear: number | string;
    expMonth: number | string;
    csv: number | string;
    details?: {
        name?: string;
        address?: {
            postal_code?: string;
        };
    };
};
export type PaymentAccount = {
    _id?: string;
    username: string;
    balance: number;
    subscriptions: {
        _id: string;
        created: Date;
        interval: number;
    }[];
};
export type PaymentOptions = {
    /** Path to payment page */
    paymentUrl?: string;
};
export type PaymentTransaction = Meta & {
    /** Deliver to user/email */
    recipient: string;
    /** Purchased items */
    receipt: {
        _id: number | string;
        name: string;
        quantity: number;
        price: number;
    }[];
    /** Transaction total */
    total: number;
    /** Completion method (card, cash, etc) */
    method?: string;
    /** Stripe transaction */
    tx?: any;
};
export type Purchase = {
    target: 'balance' | string | number;
    amount?: number;
};
export declare class Payments extends PathEventEmitter {
    readonly opts: PaymentOptions;
    private readonly api;
    private loaded;
    stripe?: any;
    token?: string;
    constructor(api: Api | string, opts?: PaymentOptions);
    private checkout;
    private init;
    history(username?: string): Promise<any[]>;
    products(id?: string | number): Promise<any[]>;
    payment(card: Card, token: string): Promise<any>;
    paymentForm(element: string, token: string): Promise<() => Promise<any>>;
    /**
     * Complete payment via Momentum's payment page
     * @param {string} token Stripe payment intent secret
     * @param {string} host Host origin attempting to login
     * @return {Promise<string>} Token on success
     */
    paymentRedirect(token: string, host?: string): Promise<string>;
}
//# sourceMappingURL=payments.d.ts.map